#
# spec file for package labwc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with     warp
%bcond_without  xwayland
%define swname  wlroots
%define swver   0.17.4
%define slname  libsfdo
%define slver   0.1.3
Name:           labwc
Version:        0.8.1
Release:        1.3
Summary:        A Wayland window-stacking compositor
License:        GPL-2.0-only
URL:            https://github.com/labwc/labwc
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        https://gitlab.freedesktop.org/vyivel/libsfdo/-/archive/v%{slver}/%{slname}-v%{slver}.tar.bz2
%if %{with warp}
Source2:        https://gitlab.freedesktop.org/wlroots/wlroots/-/archive/%{swver}/%{swname}-%{swver}.tar.bz2
Provides:       bundled(wlroots)
BuildRequires:  glslang-devel
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(hwdata)
BuildRequires:  pkgconfig(libdisplay-info)
BuildRequires:  pkgconfig(libliftoff)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-renderutil)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xcb-xkb)
%if %{with xwayland}
BuildRequires:  pkgconfig(xcb-errors)
BuildRequires:  pkgconfig(xwayland)
%endif
BuildRequires:  pkgconfig(xwaylandproto)
%else
BuildRequires:  pkgconfig(wlroots-0.18)
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  scdoc
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libinput) >= 1.14
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libseat)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(xkbcommon)
Recommends:     alacritty
Recommends:     xwayland
Suggests:       rofi-wayland
Suggests:       grim
Suggests:       swaybg
Suggests:       waybar

%description
Labwc is a wlroots-based window-stacking compositor for wayland, inspired
by openbox.

%lang_package

%prep
%autosetup
%if %{with warp}
mkdir subprojects/%{swname}
tar -xf %{SOURCE2} --strip-components 1 -C subprojects/%{swname}
%endif

mkdir subprojects/%{slname}
tar -xf %{SOURCE1} --strip-components 1 -C subprojects/%{slname}

%build
%meson \
    -Dman-pages=enabled \
%if %{with xwayland}
    -Dxwayland=enabled \
%else
    -Dxwayland=disabled \
%endif
    -Dnls=enabled
%meson_build

%install
%meson_install --skip-subprojects
install -Dm 0644 docs/*.xml -t %{buildroot}%{_sysconfdir}/xdg/%{name}/

%find_lang %{name}

%files
%license LICENSE
%doc NEWS.md README.md
%{_bindir}/%{name}
%dir %{_sysconfdir}/xdg/%{name}
%config(noreplace) %{_sysconfdir}/xdg/%{name}/menu.xml
%config(noreplace) %{_sysconfdir}/xdg/%{name}/rc.xml
%dir %{_datadir}/wayland-sessions
%{_datadir}/xdg-desktop-portal
%{_datadir}/wayland-sessions/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/labwc*.svg
%{_mandir}/man?/%{name}*.?%{?ext_man}
%{_datadir}/doc/%{name}/

%files lang -f %{name}.lang

%changelog
* Fri Oct 25 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.8.1
  * Add titlebar window icons and layout configuration
  * Support for the cosmic-workspace protocol and the openbox
    inspired client-list-combined-menu for a better user experience
    with workspaces.
- add libsfdo submodule: to enable titlebar window icons and layout
* Sun Aug 18 2024 Richard Rahl <rrahl0@opensuse.org>
- switch to GPL2-only, as thats what the src files say
- remove Recommends: %%{name}-lang, so zypper can decide if needed or
  not
* Fri Aug 16 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.8.0
  + The main focus in this release has been to port labwc to
    wlroots 0.18 and to grind out associated regressions.There are
    a couple of regression warnings when using wlroots 0.18:
  - There appears to be an issue with increased commit failures,
    particularly with intel drivers. If this turns out to be an
    issue for anyone please try running with WLR_DRM_NO_ATOMIC=1.
  - Fullscreen VRR is broken but should be fixed once wlroots
    0.18.1 is released.
  + Added
  - Add options fullscreen and fullscreenForced.
  - Optionally allow keybindings when session is locked, which
    for example can be useful for volume settings.
  - Add resistance when dragging tiled/maximized windows.
  - Implement support for renderer loss recovery.
  - Support xinitrc scripts to configure XWayland server on
    launch.
  - Add theme option window.button.width to set window button
    size.
  - Add cascade placement policy.
  - Support relative tablet motion.
  + Fixed
  - Make tablet rotation follow output rotation.
  - Fix error when launching windowed Chromium.
  - Fix empty XKB_DEFAULT_LAYOUT bug.
  - Take into account CSD borders when unconstraining XDG popups.
  - Choose xdg-popup output depending on xdg-positioner.
  - Fix wlroots-0.18 regression causing flicker with some layer-
    shell clients like fuzzel on launch.
  - Fix incorrect condition in server-side-deco logic.
  - Fix flicker of snapped windows in nested session.
  - Fix tearing with atomic mode setting.
  - Handle initially maximized and fullscreen xdg-shell windows
    better.
  - Set initial geometry of maximized and fullscreen XWayland
    windows in the map_request handler to avoid visual glitches
    with some apps.
  - Disable pango glyph position rounding to avoid text geometry
    jump around when changing scale.
  + Changed
  - Make windows stay fullscreen when associated output is
    disconnected.
- Change wlroots-devel BuildRequires to pkgconfig(wlroots-0.18)
- Fix conditional xwayland on wlroots
* Fri Aug  2 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to wlroots version 0.17.4
  - render/pixman: Improve transform performance
  - render/pixman: Fix non-uniform scale with rotation
  - wlr_surface: update get_root_surface() docs
  - output: reset hardware_cursor on failure
  - scene: fix double scaling of opaque region for blend mode
    optimization
  - xdg-toplevel: allow edge_none for resizing
  - output: extract hardware cursor disabling logic
  - output: disable hardware cursor when falling back to software
  - render/vulkan: fix texture clip region leak
  - render/vulkan: free pipeline layouts on destroy
  - render/vulkan: free render format setups on destroy
  - backend/x11: send correct keyboard layout
  - xdg-popup: don't emit parent's new_popup signal too early
  - xdg-popup: validate positioner on reposition request
  - input-method: unmap popup surfaces on deactivate
  - backend/wayland: destroy ignored tablet proxies
  - backend/drm: add support for libliftoff v0.5.0
  - render/vulkan: don't use UNDEFINED layout for imported DMA-BUFs
  - wlr_pointer_gestures_v1: init destroy signal
  - wlr_pointer_gestures_v1: emit destroy signal in destroy function
  - backend/libinput: Fix call of handle_libinput_readable() when
    WLR_LIBINPUT_NO_DEVICES is set
- Build under submodule wlroots v0.17.4
- add pkgconfig(xwayland) BuildRequires: enable xwayland on wlroots
- add pkgconfig(xcb-errors) BuildRequires: enable xcb-errors util
  library on wlroots
* Fri Jul 19 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.7.4
  + Fixed
  - Make SSD borders respect snapped state on Reconfigure.
  - Fix magnifier by disabling direct scanout when active.
  - Fix crash triggered by pipemenu without parent <menu>
    element.
* Fri Jul 12 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.7.3
  + Added
  - Add config option `<core><xwaylandPersistence>` to support
    keeping XWayland alive even when no clients are connected.
  - Support xdg-shell protocol v3 with popup repositioning.
    which adds support on the wlroots side.
  - Add action `ToggleTabletMouseEmulation`.
  - Implement `<resize><drawContents>`.
  - Add `onRelease` option to `<keybind>` in support of binding
    `Super_L` to a menu.
  - Add initial support for `security-context-v1`
    (user configurable blocklists are still missing).
  - Add support for `tablet-v2-manager`.
  - Add action `UnMaximize`.
  - Support multiple IME popups.
  - Add `All` context for mouse bindings which need to be
    handled irrespective of the mouse pointer location. This
    enables Super+mouse-scroll to change magnification.
  - Add `SetDecorations` action.
  - Add `policy` option to `AutoPlace` action.
  - Add window type filter to If-actions.
  - Add screen magnifier which can be controlled with the
    `ZoomIn`, `ZoomOut` and `ToggleMagnify` actions.
  + Fixed
  - When looking for menu.xml, go through all paths rather than
    just giving up if not found in the first path searched.
    This makes it consistent with how other config/theme files
    are handled.
  - Fix memory leaks in theme.c and menu.c.
  - Fix session-lock bugs related to keyboard focus.
    + Clear focused surface on lock
    + Restore focused view on unlock
  - Fix memory leak in ssd/ssd-shadow.c
  - Respect `menu.overlap.x` when using pipemenus.
  - Do not try to restore windows to very small width/height on
    unmaximize.
  - Conditially set squared server-side decoration (SSD) corners
    when a view is tiled.
  - Remember initial direction when starting window-cycling with
    `PreviousView`. Also make the toggling of direction when
    shift is pressed relative to the initial direction.
  - Show dnd icon above layer-shell surfaces.
  - Initialize locale after reading environment files so that
    client-menu items and workspace names follow the env var
    `LANG` should that be set in `~/.config/labwc/environment`
    (which is not recommended, but we prefer to handle it
    properly if it is).
  - Fix crash on `menu.xml` containing `<item>` without a
    parent `<menu>`.
  - Reset XWayland cursor image on cursor theme reload to avoid
    trying to read destroyed pixel data.
  - Prevent child views from opening outside of usable area.
  - Fix IME popups issues (flicker when popup surface is
    initially mapped and incorrectly showing multiple popups).
  - Rate-limit cursor-driven resize events based on monitor's
    refresh rate. This fixes the lag when resizing windows of
    some apps on XWayland, for example Chromium and Steam.
  - Session-lock: fix flashing & update cursor shape.
  - Remove tearing-controller listeners on destroy.
  - Handle invalid `ForEach` and `If` action cofigs.
  - Delay startup of applications until event loop is ready.
  - With `SendToDesktop` action follow=no option, ensure the
    topmost window is focused.
  - Prevent XWayland from using incorrect keymap.
  - Allow keybinds containing the hyphen key to be defined
    with `-`.
  - Show/hide `top` layer more smartly. Before this commit,
    `top` layers were hidden whenever there was a fullscreen
    window in the corresponding output. With this commit,
    `top` layers are hidden only when there is a fullscreen
    window without other windows above it in the
    corresponding output.
  + Changed
  - Remove subprojects/seatd.wrap as no longer needed
  - Action `MoveToCursor` is deprecated in favour of:
    `<action name="AutoPlace" policy="cursor"/>`.
- Recommends alacritty instead foot as default terminal
* Fri May 10 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.7.2
  + Added
  - Add <menu><ignoreButtonReleasePeriod> to prevent clicks with
    small movements from inadvertantly closing a menu or
    selecting a menu item.
  - Support drop-shadows (disabled by default) for windows using
    server-side decorations.
  - Add window-rule ignoreConfigureRequest to ignore X11
    client-side configure requests (positioning and resizing).
  - Support window-rules based on window type:
    <windowRule type="">, where type can be for example
    NET_WM_WINDOW_TYPE_DESKTOP for an XWayland window.
  - Add none branch to the ForEach action.
  - Add -S|--session <command> option to start <command> on
    startup and to terminate the compositor when exits.
  - In theme setting color definitions, support inline alpha
    encoding like #aabbccff
  - Add window-switcher custom field inspired by printf
    formatting.
  - Support defining window-switcher width as a percentage of
    output (display) width.
  - Support Openbox compatible pipe-menus.
  - Add snap-to-edge overlay.
  - This includes the following new config and theme settings.
  - Add theme settings listed below for window-switcher preview
    border.
  - Support libinput config option for calibration matrices.
  - Add new window-switcher field content types workspace, state,
    type_short and output.
  - Support input methods.
  - Add atCursor attribute to action ShowMenu so that a window's
    "client-menu" could optionally be launched at the pointer
    using a keybind.
  - Support workspace-prefix (<desktops><prefix>) for workspace-
    switcher onscreen display when naming workspaces by digits.
  - Process all *.env files in an environment.d directory
    alongside and in the same way as each potential environment
    file.
  - Allow empty variables in environment files.
  - Add optional headless fallback output that is automatically
    created when no other output exists.
  - Optionally show windows on all workspaces in window-switcher.
  - Handle touch on headerbar using cursor emulate events.
  - Updated dbus activation environment with more environment
    variables.
  - Run shutdown script on exit
  - Add wrap argument to action MoveToOutput.
  + Fixed
  - Prevent Chromium from crashing when started after a virtual
    keyboard is destroyed.
  - Fix top-layer not showing when there is a minimized full-
    screen window.
  - Prevent the following whilst window-switcher cycling
  - Prevent shaded XWayland windows from getting cursor events.
  - Fix menu-parser use-after-free bug.
  - Update top layer visibility on map to fix bug with Steam's
    Big Picture Mode.
  - window which requests fullscreen before mapping.
  - Do not update server-side-decoration if window is too small.
  - Fix crash on Kill action with XWayland windows.
  - Update workspaces on --reconfigure.
  - Notify idle manager when emulating cursor movement.
  - Fix GrowToEdge/ShrinkToEdge action bug caused by clients
    ignoring the requested size, for example a terminal honouring
    size-hints. Fix assert() on VT switch.
  - Ensure titlebar has consistent look when using transparency.
  - Fix dnd bug where dnd does not finish properly on cursor-
    button-release if there is no surface under the cursor such
    as on the desktop when no background client is running.
  - Send cursor-button release event to CSD client before
    finishing window dragging to avoid a bug whereby the release
    event is incorrectly sent to a layer-shell client at the end
    of a drag.
  - Validate double-click against SSD part type because clicks on
    different parts of a client in quick succession should not be
    interpreted as a double click.
  - Fix bug that region overlay is not shown when a modifier key
    is re-pressed.
  - Fix workspace-switcher on-screen-display positioning of text
    using right-to-left (RTL) locales.
  - Unconstrain xdg-shell popups to usable area (rather than full
    output) so that popups do not cover layer-shell clients such
    as panels.
  - Exclude unfocusable XWayland windows.
  - Render text buffers with opaque backgrounds because subpixel
    text rendering over a transparent background does not work
    properly with cairo/pango.
  - Fallback on layout 'us' if a keymap cannot be created for the
    provided XKB_DEFAULT_LAYOUT. If keymap still cannot be
    created, exit with a helpful message instead of a segv crash.
  - Reload cursor theme and size on reconfigure.
  - Fix a number of surface-focus related short-comings.
  - Fix move/resize bug manifesting itself on touchpad taps.
  - Include always-on-top windows in window-switcher.
  - Make resize flicker free again when running labwc nested.
  - Clean up dbus and systemd activation environments on exit
  - Fix view_get_adjacent_output() bug resulting in often
    returning an incorrect output when using more than two
    outputs.
  + Changed
  - Support press-move-release when interacting with the labwc
    root-menu.
  - In theme settings, mark color definitions in the format use
    [#]rrggbbaa instead #rrggbb aaa (deprecated).
  - If your rc.xml contains a keybind to show menu "client-menu".
  - Change action MoveToOutput argument 'name' to 'output'
  - Do not deactivate window when giving keyboard focus to a non-
    view surface such as a popup or layer-shell surface. This
    matches Openbox behavior.
  - Treat Globally Active XWayland windows according to type to
    fix focus issues with IntelliJ IDEA and JDownloader 2.
  - Also revert f6e3527 which allowed re-focus between Globally
    Active XWayland windows of the same PID.
  - Only update dbus and systemd activation environments when
    running on the DRM backend or by explicit request using
    environment variable LABWC_UPDATE_ACTIVATION_ENV.
* Sat Mar 16 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Enable xwayland feature
* Fri Mar  1 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.7.1
  + Added
  - Support libinput option sendEventsMode to allow
    enabling/disabling devices.
  - Add click method libinput option.
  - Add data/labwc.svg & data/labwc-symbolic.svg, and specify
    icon name in labwc.desktop to enable Display Managers to show
    an icons for labwc.
  - Expose output configuration test to clients.
    For example, this enables wlr-randr --dryrun
  - Add window-edge resistance for interactive moves/resizes and
    support negative strengths to indicate attractive snapping.
  - Set keyboard layout on reconfigure.
  - Reset keyboard-layout group (index) for each window on
    reconfigure if the keymap has changed.
  - Support merging multiple config files with the
  - -merge-config command line option.
  - Add config option to map touch events to a named output
    (display). Optionally, make this only apply to specific named
    devices.
  - Add tablet support including:
    + Mapping of tablet to output (display)
    + Emulation of cursor movement and button press/release
    + Configuration of area and rotation
  - Add tearing support.
  - Add configuration support for mouse buttons Side, Extra,
    Forward, Back and Task.
  - config: allow <libinput><device> without category attribute
    to define a default profile because it is more user-friendly
    and intuitive.
  - Add a configuration option to enable adaptive sync only when
    an application is in fullscreen mode.
  - Add touchpad libinput device type to increase configuration
    flexibility, for example allowing naturalScroll on touchpads,
    but not on regular pointer devices such as mice.
  - Add actions:
    + AutoPlace
    + MoveToOutput, FitToOutput
    + Shade, Unshade, ToggleShade
  - Add config option <placement><policy> with supported values
    center, cursor and automatic. The latter minimizes overlap
    with other windows already on screen and is similar to
    Openbox's smart window placement.
  + Fixed
  - Delay popup-unconstrain until after first commit in response
    to a changed wlroots 0.17 interface and to get rid of the
    error message below.
  - Notify clients about configuration errors when changing
    output settings.
  - Fix output configuration bug causing compositor crash when
    refresh rate is zero.
  - Fix disappearing cursor bug on view destruction. Issue #1393
  - Use used specified config-file (using -c command line option)
    on reconfigure.
  - Assign outputs to new views on surface creation instead of
    mapping, and notify the client of the preferred output scale
    when doing so.
  - Fix crash when a minimized fullscreen window closes.
  - Execute menu actions after closing menus so that menu
    entries can issue wtype commands to the surface with
    keyboard-focus.
  - Try to honor original window geometry on layout changes.
  - Fix virtual keyboard bug experienced with wlrctl keyboard
    type xyz. Do not process virtual keyboard keycodes (just the
    keysyms).
  - Sync xdg-shell client view->pending when applying geometry
    to fix issue caused by applications choosing not respond to
    pending resize requests either by ignoring them or
    substituting alternative sizes (for example, when mpv
    constrains resizes to keep its aspect ratio fixed).
  + Changed
  - Make MoveToCursor honour <core><gap>.
  - Add Roll Up/Down client-menu entry for ToggleShade
  - When a Wayland-native window is snapped to a screen edges or
    user-defined region, labwc will notify the application that
    it is "tiled", allowing the application to better adapt its
    rendering to constrained layouts. Windows with client-side
    decorations may respond to these notices by squaring off
    corners and, in some cases, disabling resize abilities.
  - When a window is dragged from a snapped position (either a
    screen edge or a user-defined region), the snapped state is
    now discarded as soon as the dragging begins.
  - The new windowEdgeStrength setting makes windows resist
    interactive moves and resizes across the edges of other
    windows.
  - Run menu actions on button release intead of press.
  - Constrain window size to that of usable area when an
    application is started.
  - Support showing the full app_id in the window switcher. Users
    with a custom windowSwitcher configuration should use the
    trimmed_identifier field label to preserve existing behavior;
    the identifier field now refers to the full app_id. Consult
    the labwc-config(5) manual page for more details.
- Add hicolor-icon-theme BuildRequires: fix icons directory
* Thu Jan 11 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Remove openbox themes that cause conflict.
* Thu Jan 11 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- update to version 0.7.0
  + The main effort in this release has gone into porting labwc to
    wlroots 0.17 and tidying up regressions. Nonetheless, it
    contains a significant number of additions and fixes as
    described below. Should bug fixes be required against 0.6.6
    (built with wlroots 0.16), a 0.6 branch will be created.
  + Additions:
  - Support titlebar hover icons. Written-by: @spl237
  - Add theme options osd.workspace-switcher.boxes.{width,height}
    Written-by: @kyak
  - Add actions VirtualOutputAdd and VirtualOutputRemove to con-
    trol virtual outputs. Written-by: @kyak (gh#labwc/labwc#1287)
  - Teach MoveToEdge to move windows to adjacent outputs.
    Written-by: @ahesford
  - Implement <font place="InactiveWindow">. Written-by: @ludg1e
    (gh#labwc/labwc#1292)
  - Implement cursor-shape-v1 protocol to allow Wayland clients
    to request a buffer for a cursor shape from a compositor.
    Written-by: @heroin-moose
  - Implement fractional-scale-v1 protocol to allow Wayland
    clients to properly scale on outputs with fractional scale
    factor. Written-by: @heroin-moose
  - Add ResizeTo action (gh#labwc/labwc#1261)
  - Allow going backwards in window-switcher OSD by using
    arrow-up or arrow-left. Written-by: @jp7677
  - Add ToggleOmnipresent action and add an "Always on Visible
    Workspace" entry for it in the client-menu under the
    Workspaces submenu. Written-by: @bnason
  - Account for space taken up by XWayland clients with
    _NET_WM_STRUT_PARTIAL property in the usable_area
    calculation. This increases inter-operability with X11
    desktop componenets.
  - Set XWayland's _NET_WORKAREA property based on usable area.
    XWayland clients use the _NET_WORKAREA root window property
    to determine how much of the screen is not covered by
    panels/docks. The property is used for example by Qt to
    determine areas of the screen that popup menus should not
    overlap.
  + Fixed:
  - Fix xwayland.c null pointer dereference causing crash with
    CLions. (gh#labwc/labwc#1352)
  - Fix issue with XWayland surfaces completely offscreen not
    generating commit events and therefore preventing them from
    moving onscreen.
  - Do not de-active windows when layer-shell client takes
    keyboard focus, to fix sfwbar minimize action.
    (gh#labwc/labwc#1342)
  - Move layer-shell popups from the background layer to the
    top layer to render them above normal windows. Previously
    this was only done for the bottom layer. In support of
    Raspberry Pi's pcmanfm --desktop. (gh#labwc/labwc#1293)
  - Calculate usable_area before positioning clients to ensure it
    is correct before non exclusive-zone layer-shell clients are
    positioned or resized. (gh#labwc/labwc#1285)
  - Prevent overriding XWayland maximized/fullscreen/tiled
    geometry to fix an issue where some XWayland views (example:
    xfce4-terminal) do not end up with exactly the correct
    geometry when tiled.
  + Changed:
  - Treat XWayland panel windows as if fixedPosition rule is set
  - Use the GTK3 notebook header color as the default active
    title color (small change from #dddad6 to #e1dedb).
    Written-by: @dimkr
* Wed Apr 12 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- update to version 0.6.2
* Sat Nov 19 2022 Андрей Алыпов <and.november@opensuse.org>
- update to version 0.6.0
* Sun Mar  7 2021 Андрей Алыпов <and.november@opensuse.org>
- initial package (version 0.1.0) for openSUSE
